headers needed to compile on Solaris

diff --git a/proxy/libvirt_proxy.c b/proxy/libvirt_proxy.c
--- a/proxy/libvirt_proxy.c
+++ b/proxy/libvirt_proxy.c
@@ -18,6 +18,8 @@
 #include <sys/socket.h>
 #include <sys/un.h>
 #include <locale.h>
+#include <strings.h>
+
 #include "internal.h"
 
 #ifdef WITH_XEN
diff --git a/src/proxy_internal.c b/src/proxy_internal.c
--- a/src/proxy_internal.c
+++ b/src/proxy_internal.c
@@ -18,6 +18,7 @@
 #include <sys/socket.h>
 #include <sys/un.h>
 #include <sys/wait.h>
+#include <string.h>
 #include "internal.h"
 #include "driver.h"
 #include "proxy_internal.h"
diff --git a/src/qemu_internal.c b/src/qemu_internal.c
--- a/src/qemu_internal.c
+++ b/src/qemu_internal.c
@@ -41,7 +41,12 @@
 #include <netinet/in.h>
 #include <netdb.h>
 #include <limits.h>
+#ifdef __linux__
 #include <paths.h>
+#else
+#define	_PATH_DEVNULL	"/dev/null"
+#endif
+
 
 #include "internal.h"
 #include "qemu_internal.h"
diff --git a/src/test.c b/src/test.c
--- a/src/test.c
+++ b/src/test.c
@@ -31,6 +31,7 @@
 #include <libxml/uri.h>
 #include <fcntl.h>
 #include <unistd.h>
+#include <strings.h>
 
 #include "internal.h"
 #include "test.h"
diff --git a/src/virsh.c b/src/virsh.c
--- a/src/virsh.c
+++ b/src/virsh.c
@@ -20,6 +20,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <strings.h>
 #include <stdarg.h>
 #include <unistd.h>
 #include <errno.h>
@@ -39,6 +40,10 @@
 
 #include <readline/readline.h>
 #include <readline/history.h>
+
+#ifndef __linux__
+#include <iso/limits_iso.h>
+#endif
 
 #include "config.h"
 #include "internal.h"
diff --git a/src/xen_unified.c b/src/xen_unified.c
--- a/src/xen_unified.c
+++ b/src/xen_unified.c
@@ -27,6 +27,7 @@
 
 #include <stdint.h>
 #include <unistd.h>
+#include <string.h>
 #include <sys/types.h>
 #include <xen/dom0_ops.h>
 
diff --git a/src/xend_internal.c b/src/xend_internal.c
--- a/src/xend_internal.c
+++ b/src/xend_internal.c
@@ -28,6 +28,8 @@
 #include <arpa/inet.h>
 #include <netdb.h>
 #include <libxml/uri.h>
+#include <errno.h>
+#include <strings.h>
 
 #include "libvirt/libvirt.h"
 #include "driver.h"
diff --git a/src/xm_internal.c b/src/xm_internal.c
--- a/src/xm_internal.c
+++ b/src/xm_internal.c
@@ -26,6 +26,8 @@
 #include <dirent.h>
 #include <time.h>
 #include <sys/stat.h>
+#include <strings.h>
+#include <limits.h>
 
 #include <unistd.h>
 #include <stdint.h>
@@ -35,6 +37,9 @@
 #include <libxml/tree.h>
 #include <libxml/xpath.h>
 
+#ifndef __linux__
+#define	NAME_MAX	14
+#endif
 
 #include "xen_unified.h"
 #include "xm_internal.h"
diff --git a/tests/testutils.c b/tests/testutils.c
--- a/tests/testutils.c
+++ b/tests/testutils.c
@@ -19,8 +19,13 @@
 #include <unistd.h>
 #include <fcntl.h>
 #include <limits.h>
+#include "testutils.h"
+
+#ifdef __linux__
 #include <paths.h>
-#include "testutils.h"
+#else
+#define	_PATH_DEVNULL	"/dev/null"
+#endif
 
 #define GETTIMEOFDAY(T) gettimeofday(T, NULL)
 #define DIFF_MSEC(T, U)                                 \
diff --git a/tests/virshtest.c b/tests/virshtest.c
--- a/tests/virshtest.c
+++ b/tests/virshtest.c
@@ -2,6 +2,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <unistd.h>
+#include <limits.h>
 
 #include "xml.h"
 #include "testutils.h"
